# {py:mod}`itkwasm.text_stream`

```{py:module} itkwasm.text_stream
```

```{autodoc2-docstring} itkwasm.text_stream
:allowtitles:
```

## Module Contents

### Classes

````{list-table}
:class: autosummary longtable
:align: left

* - {py:obj}`TextStream <itkwasm.text_stream.TextStream>`
  - ```{autodoc2-docstring} itkwasm.text_stream.TextStream
    :summary:
    ```
````

### API

`````{py:class} TextStream
:canonical: itkwasm.text_stream.TextStream

```{autodoc2-docstring} itkwasm.text_stream.TextStream
```

````{py:attribute} data
:canonical: itkwasm.text_stream.TextStream.data
:type: str
:value: >
   None

```{autodoc2-docstring} itkwasm.text_stream.TextStream.data
```

````

`````
